mirror of https://lore.kernel.org/lkml/
 help / color / mirror / Atom feed
* [PATCH] 2.4.10-pre14: AMD 761 AGP GART (again and again)
@ 2001-09-23  4:01 Robert Love
  0 siblings, 0 replies; only message in thread
From: Robert Love @ 2001-09-23  4:01 UTC (permalink / raw)
  To: linux-kernel

My AMD 761 patch was applied in 2.4.10-pre10 but removed during a later
merge with Alan's tree.  Now Alan's 2.4.9-ac14 has this patch.  It is
pending in Linus's tree, but I have received some requests for it, so
here it is.  It applies fine to 2.4.10-pre13 and 14.


diff -urN linux-2.4.10-pre14/Documentation/Configure.help linux/Documentation/Configure.help
--- linux-2.4.10-pre14/Documentation/Configure.help	Thu Sep 20 13:32:23 2001
+++ linux/Documentation/Configure.help	Thu Sep 20 13:33:42 2001
@@ -2578,10 +2578,10 @@
   the GLX component for XFree86 3.3.6, which can be downloaded from
   http://utah-glx.sourceforge.net/ .
 
-AMD Irongate support
+AMD Irongate, 761, and 762 support
 CONFIG_AGP_AMD
   This option gives you AGP support for the GLX component of the
-  XFree86 4.x on AMD Irongate and 761 chipsets.
+  XFree86 4.x on AMD Irongate, 761, and 762 chipsets.
 
   For the moment, you should probably say N, unless you want to test
   the GLX component for XFree86 3.3.6, which can be downloaded from
diff -urN linux-2.4.10-pre14/drivers/char/Config.in linux/drivers/char/Config.in
--- linux-2.4.10-pre14/drivers/char/Config.in	Thu Sep 20 13:31:44 2001
+++ linux/drivers/char/Config.in	Thu Sep 20 13:34:03 2001
@@ -208,7 +208,7 @@
    bool '  Intel 440LX/BX/GX and I815/I840/I850 support' CONFIG_AGP_INTEL
    bool '  Intel I810/I815 (on-board) support' CONFIG_AGP_I810
    bool '  VIA chipset support' CONFIG_AGP_VIA
-   bool '  AMD Irongate and 761 support' CONFIG_AGP_AMD
+   bool '  AMD Irongate, 761, and 762 support' CONFIG_AGP_AMD
    bool '  Generic SiS support' CONFIG_AGP_SIS
    bool '  ALI chipset support' CONFIG_AGP_ALI
    bool '  Serverworks LE/HE support' CONFIG_AGP_SWORKS
diff -urN linux-2.4.10-pre14/drivers/char/agp/agp.h linux/drivers/char/agp/agp.h
--- linux-2.4.10-pre14/drivers/char/agp/agp.h	Thu Sep 20 13:31:44 2001
+++ linux/drivers/char/agp/agp.h	Thu Sep 20 13:35:12 2001
@@ -202,6 +202,9 @@
 #ifndef PCI_DEVICE_ID_AMD_IRONGATE_0
 #define PCI_DEVICE_ID_AMD_IRONGATE_0    0x7006
 #endif
+#ifndef PCI_DEVICE_ID_AMD_761_0
+#define PCI_DEVICE_ID_AMD_761_0         0x700e
+#endif
 #ifndef PCI_DEVICE_ID_AMD_762_0
 #define PCI_DEVICE_ID_AMD_762_0		0x700C
 #endif
diff -urN linux-2.4.10-pre14/include/linux/agp_backend.h linux/include/linux/agp_backend.h
--- linux-2.4.10-pre14/include/linux/agp_backend.h	Thu Sep 20 13:31:33 2001
+++ linux/include/linux/agp_backend.h	Thu Sep 20 13:37:23 2001
@@ -59,6 +59,7 @@
 	AMD_GENERIC,
 	AMD_IRONGATE,
 	AMD_761,
+	AMD_762,
 	ALI_M1541,
 	ALI_M1621,
 	ALI_M1631,



diff -urN linux-2.4.10-pre14/drivers/char/agp/agpgart_be.c linux/drivers/char/agp/agpgart_be.c
--- linux-2.4.10-pre14/drivers/char/agp/agpgart_be.c	Thu Sep 20 13:31:44 2001
+++ linux/drivers/char/agp/agpgart_be.c	Thu Sep 20 13:37:26 2001
@@ -388,8 +388,8 @@
  * Driver routines - start
  * Currently this module supports the following chipsets:
  * i810, i815, 440lx, 440bx, 440gx, i840, i850, via vp3, via mvp3,
  * via kx133, via kt133, amd irongate, amd 761, ALi M1541, and generic
  * support for the SiS chipsets.
  */
 
 /* Generic Agp routines - Start */
@@ -2931,9 +2931,15 @@
 		"AMD",
 		"Irongate",
 		amd_irongate_setup },
+	{ PCI_DEVICE_ID_AMD_761_0,
+		PCI_VENDOR_ID_AMD,
+		AMD_761,
+		"AMD",
+		"761",
+		amd_irongate_setup },
 	{ PCI_DEVICE_ID_AMD_762_0,
 		PCI_VENDOR_ID_AMD,
-		AMD_IRONGATE,
+		AMD_762,
 		"AMD",
 		"AMD 760MP",
 		amd_irongate_setup },
@@ -388,8 +388,8 @@
  * Currently this module supports the following chipsets:
  * i810, i815, 440lx, 440bx, 440gx, i840, i850, via vp3, via mvp3,
- * via kx133, via kt133, amd irongate, amd 761, ALi M1541, and generic
- * support for the SiS chipsets.
+ * via kx133, via kt133, amd irongate, amd 761, amd 762, ALi M1541,
+ * and generic support for the SiS chipsets.
  */
 
-- 
Robert M. Love
rml at ufl.edu
rml at tech9.net


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2001-09-23  4:01 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2001-09-23  4:01 [PATCH] 2.4.10-pre14: AMD 761 AGP GART (again and again) Robert Love

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox

all inboxes | Powered by JetHome®